from django.template.loader import render_to_string
from django.http import JsonResponse, HttpResponse
from weasyprint import HTML
import tempfile
import datetime

def pdfview(logourl, templatepath, styles, data):

    response = HttpResponse(content_type='application/pdf')
    response['Content-Disposition'] = 'inline; attachment; filename=DailyTransaction' + \
        str(datetime.datetime.now())+'.pdf'
    
    response['Content-Transfer-Encoding'] = 'binary'

    context = {
        "logourl": logourl,
        "data" : data
    }

    html_string = render_to_string(templatepath, context)
    html = HTML(string=html_string)


    result = html.write_pdf(
        stylesheets=styles
    )

    with tempfile.NamedTemporaryFile(delete=True) as output:
        output.write(result)
        output.flush()

        output = open(output.name, 'rb')
        response.write(output.read())

    return response


from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Developers',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
setup(
  name='djpdfview',
  version='1.0.0',
  description='Working with pdf made easy',
  long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
  long_description_content_type='text/markdown',
  url='https://himelrana.com',  
  author='Himel',
  author_email='contact@himelrana.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='pdfview in django', 
  packages=find_packages(),
  python_requires='>=3.6',
  install_requires=[] 
)
